package com.chelvc.framework.database.handler;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;
import java.util.List;

import com.chelvc.framework.base.context.JacksonContextHolder;
import com.fasterxml.jackson.core.type.TypeReference;
import org.apache.ibatis.type.BaseTypeHandler;
import org.apache.ibatis.type.JdbcType;
import org.springframework.util.CollectionUtils;

/**
 * 单精度浮点数列表字段处理实现
 *
 * @author Woody
 * @date 2024/1/30
 */
public class FloatsTypeHandler extends BaseTypeHandler<List<Float>> {
    /**
     * 类型引用实例
     */
    private static final TypeReference<List<Float>> REFERENCE = new TypeReference<List<Float>>() {
    };

    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, List<Float> parameter, JdbcType jdbcType)
            throws SQLException {
        if (CollectionUtils.isEmpty(parameter)) {
            ps.setNull(i, Types.VARCHAR);
        } else {
            ps.setString(i, JacksonContextHolder.serialize(parameter));
        }
    }

    @Override
    public List<Float> getNullableResult(ResultSet rs, String columnName) throws SQLException {
        return JacksonContextHolder.deserialize(rs.getString(columnName), REFERENCE);
    }

    @Override
    public List<Float> getNullableResult(ResultSet rs, int columnIndex) throws SQLException {
        return JacksonContextHolder.deserialize(rs.getString(columnIndex), REFERENCE);
    }

    @Override
    public List<Float> getNullableResult(CallableStatement cs, int columnIndex) throws SQLException {
        return JacksonContextHolder.deserialize(cs.getString(columnIndex), REFERENCE);
    }
}
