package com.chelvc.framework.database.handler;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;
import java.util.List;

import com.chelvc.framework.base.context.JacksonContextHolder;
import com.chelvc.framework.common.model.Region;
import com.fasterxml.jackson.core.type.TypeReference;
import org.apache.ibatis.type.BaseTypeHandler;
import org.apache.ibatis.type.JdbcType;

/**
 * 地区字段处理实现
 *
 * @author Woody
 * @date 2024/1/30
 */
public class RegionsTypeHandler extends BaseTypeHandler<List<Region>> {
    /**
     * 类型引用实例
     */
    private static final TypeReference<List<Region>> REFERENCE = new TypeReference<List<Region>>() {
    };

    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, List<Region> parameter, JdbcType jdbcType)
            throws SQLException {
        if (parameter == null) {
            ps.setNull(i, Types.VARCHAR);
        } else {
            ps.setString(i, JacksonContextHolder.serialize(parameter));
        }
    }

    @Override
    public List<Region> getNullableResult(ResultSet rs, String columnName) throws SQLException {
        return JacksonContextHolder.deserialize(rs.getString(columnName), REFERENCE);
    }

    @Override
    public List<Region> getNullableResult(ResultSet rs, int columnIndex) throws SQLException {
        return JacksonContextHolder.deserialize(rs.getString(columnIndex), REFERENCE);
    }

    @Override
    public List<Region> getNullableResult(CallableStatement cs, int columnIndex) throws SQLException {
        return JacksonContextHolder.deserialize(cs.getString(columnIndex), REFERENCE);
    }
}
